% SCRIPT "myDDE_SISC_54.m", relevant to [3, Example 5.4].
%
% This script defines functions and parameters of the system of d linear
% Delay Differential Equations (DDEs)
%
% x'(t)=Atilde(t)x(t)
%   +sum_{u=1}^{q}Btilde_{u}(t)*x(t-d_{u})
%   +sum_{v=1}^{w}int_{-l_{v}}^{-r_{v}}Ctilde_{v}(t,theta)x(t+theta)dtheta
%
% according to the notation in [1, Chapter 7].
%
% The script can be used in
% -"eigAM.m" to approximate the eigenvalues of the infinitesimal generator
%  in the AUTONOMOUS case based on the method described in [1, Chapter 5]
%  and originally in [3].
% -"eigTMN.m" to approximate the eigenvalues of the evolution operator in
%  the NONAUTONOMOUS case based on the method described in
%  [1, Chapter 6] and originally in [2].
%
% Version 1.0, june 5, 2014. 
%
% References:
%  [1] D. Breda, S. Maset and R. Vermiglio, "Stability of linear delay
%      differential equations - A numerical approach with MATLAB", in
%      Control, Automation and Robotics, T. Basar, A. Bicchi and M. Krstic
%      eds., Springer, New York, 2015, ISBN 978-1-4939-2106-5.
%  [2] D. Breda, S. Maset and R. Vermiglio, "Approximation of eigenvalues
%      of evolution operators for linear retarded functional differential
%      equations", SIAM J. Numer. Anal. 50(3):1456-1483, 2012.
%  [3] D. Breda, S. Maset and R. Vermiglio, "Pseudospectral differencing
%      methods for characteristic roots of delay differential equations",
%      SIAM J. Sci. Comput. 27(2):482-495, 2005.

%% MEMO LIST OF POSSIBLE PARAMETERS
%par(1)=d_1;
%par(2)=c;

%% DIMENSION OF THE DDE
d=2;

%% CURRENT TIME TERM
Atilde=@(t,d,par) [-3,1;-24.646,-35.430];

%% DISCRETE DELAY TERMS
dd=par(1);
Btilde{1}=@(t,d,par) [1,0;2.35553,2.00365];

%% DISTRIBUTED DELAY TERMS
l=[.3,1];
r=[.1,.5];
Ctilde{1}=@(t,theta,d,par) [2.25,2.5;0,-par(2)*theta.^2];
Ctilde{2}=@(t,theta,d,par) [-1,0;0,-1];