% SCRIPT "myDDE_test5.m" relevant to equation (8.15) in [1, Section 8.3]
%
% This script defines functions and parameters of the system of d linear
% Delay Differential Equations (DDEs)
%
% x'(t)=Atilde(t)x(t)
%   +sum_{u=1}^{q}Btilde_{u}(t)*x(t-d_{u})
%   +sum_{v=1}^{w}int_{-l_{v}}^{-r_{v}}Ctilde_{v}(t,theta)x(t+theta)dtheta
%
% according to the notation in [1, Chapter 7].
%
% The script can be used in
% -"eigAM.m" to approximate the eigenvalues of the infinitesimal generator
%  in the AUTONOMOUS case based on the method described in [1, Chapter 5]
%  and originally in [3].
% -"eigTMN.m" to approximate the eigenvalues of the evolution operator in
%  the NONAUTONOMOUS case based on the method described in
%  [1, Chapter 6] and originally in [2].
%
% Version 1.0, june 5, 2014. 
%
% References:
%  [1] D. Breda, S. Maset and R. Vermiglio, "Stability of linear delay
%      differential equations - A numerical approach with MATLAB", in
%      Control, Automation and Robotics, T. Basar, A. Bicchi and M. Krstic
%      eds., Springer, New York, 2015, ISBN 978-1-4939-2106-5.
%  [2] D. Breda, S. Maset and R. Vermiglio, "Approximation of eigenvalues
%      of evolution operators for linear retarded functional differential
%      equations", SIAM J. Numer. Anal. 50(3):1456-1483, 2012.
%  [3] D. Breda, S. Maset and R. Vermiglio, "Pseudospectral differencing
%      methods for characteristic roots of delay differential equations",
%      SIAM J. Sci. Comput. 27(2):482-495, 2005.

%% MEMO LIST OF POSSIBLE PARAMETERS
%par(1)=a1
%par(2)=delta
%par(3)=epsilon
%par(4)=Omega
%par(5)=b1
%par(6)=b2
%par(7)=d1
%par(8)=d2

%% DIMENSION OF THE DDE
d=2;

%% CURRENT TIME TERM
Atilde=@(t,d,par) [0,1;-par(2)-par(3)*cos(par(4)*t),-par(1)];

%% DISCRETE DELAY TERMS
dd=[par(7),par(8)];
Btilde{1}=@(t,d,par) [0,0;par(5),0];
Btilde{2}=@(t,d,par) [0,0;0,par(6)];

%% DISTRIBUTED DELAY TERMS
l=[];
r=[];
Ctilde{1}=@(t,theta,d,par) [];