% SCRIPT "myDDE_test5.m" relevant to Test 5 in [1, Chapter 8]
%
% This script defines functions and parameters of the system of d linear
% Delay Differential Equations (DDEs)
%
% x'(t)=Atilde(t)x(t)
%   +sum_{u=1}^{q}Btilde_{u}(t)*x(t-d_{u})
%   +sum_{v=1}^{w}int_{-l_{v}}^{-r_{v}}Ctilde_{v}(t,theta)x(t+theta)dtheta
%
% according to the notation in [1, Chapter 7].
%
% The script can be used in
% -"eigAM.m" to approximate the eigenvalues of the infinitesimal generator
%  in the AUTONOMOUS case based on the method described in [1, Chapter 5]
%  and originally in [3].
% -"eigTMN.m" to approximate the eigenvalues of the evolution operator in
%  the NONAUTONOMOUS case based on the method described in
%  [1, Chapter 6] and originally in [2].
%
% Version 1.0, june 5, 2014. 
%
% References:
%  [1] D. Breda, S. Maset and R. Vermiglio, "Stability of linear delay
%      differential equations - A numerical approach with MATLAB", in
%      Control, Automation and Robotics, T. Basar, A. Bicchi and M. Krstic
%      eds., Springer, New York, 2015, ISBN 978-1-4939-2106-5.
%  [2] D. Breda, S. Maset and R. Vermiglio, "Approximation of eigenvalues
%      of evolution operators for linear retarded functional differential
%      equations", SIAM J. Numer. Anal. 50(3):1456-1483, 2012.
%  [3] D. Breda, S. Maset and R. Vermiglio, "Pseudospectral differencing
%      methods for characteristic roots of delay differential equations",
%      SIAM J. Sci. Comput. 27(2):482-495, 2005.

%% MEMO LIST OF POSSIBLE PARAMETERS
%par(1)=rho;
%par(2)=sigma;

%% DIMENSION OF THE DDE
d=1;

%% CURRENT TIME TERM
Atilde=@(t,d,par) cos(t);

%% DISCRETE DELAY TERMS
dd=2*pi;
Btilde{1}=@(t,d,par) sin(t)+par(1)*exp(2*pi*(par(1)+par(2)));

%% DISTRIBUTED DELAY TERMS
l=2*pi;
r=0;
Ctilde{1}=@(t,theta,d,par) (par(2))^2*exp(sin(t)-sin(t)*cos(theta)-...
    cos(t)*sin(theta)+exp(-2*pi*(par(1)+par(2)))*(cos(t)*cos(theta)-...
    sin(t)*sin(theta)-cos(t))-theta*par(1))/(1-exp(-2*pi*par(2)));